@@ -1,7 +1,7 @@
 cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL, ncores = 1) {
   
   if ( identical(csIndex, 0) ) {
-    models <- univregs(target = target, dataset = dataset, test = test, wei = wei, ncores = ncores)  
+    models <- MXM::univregs(target = target, dataset = dataset, test = test, wei = wei, ncores = ncores)  
   } else {
   
   if ( length(xIndex) > 0 ) {
@@ -14,7 +14,9 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
   # id <- Rfast::check_data(dataset)
   # if ( sum(id > 0) )  dataset[, id] <- rnorm(rows * length(id) )
   
-  options(warn = -1)
+  oop <- options(warn = -1) 
+  on.exit( options(oop) )
+	
   if ( identical(test, testIndBeta) ) {  ## Beta regression
     lik2 <- dof <- numeric( cols )
     fit1 <- beta.reg(target, dataset[, csIndex, drop = FALSE])
@@ -44,14 +46,14 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "MASS") %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "MASS") %dopar% {
         fit2 <- MASS::rlm( target ~., data = dataset[, c(csIndex, i)], maxit = 2000, method = "MM" )
         lik2 <- as.numeric( logLik(fit2) )
         return( c(lik2, length( coef(fit2) ) ) )
       }  
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- as.vector( 2 * ( mod[, 1] - lik1) )
       models$pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
     }   
@@ -74,10 +76,10 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pvalue
             
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- lm( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, y = FALSE, model = FALSE )
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         ww <- lm( target ~., data = dataset[, c(csIndex, i)], weights = wei, y = FALSE, model = FALSE )
         tab <- anova( fit1, ww )
         stat <- tab[2, 5] 
@@ -86,7 +88,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pval <- pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE )
         return( c(stat, pval) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- mod[, 2]
     }   
@@ -107,11 +109,11 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       }
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- lm( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, y = FALSE, model = FALSE )
       
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         ww <- lm( target ~., data = dataset[, c(csIndex, i)], weights = wei, y = FALSE, model = FALSE )
         tab <- anova( fit1, ww )
         stat <- tab[2, 5] 
@@ -120,7 +122,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pval <- pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE )
         return( c(stat, pval) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       stat <- mod[, 1]
       pvalue <- mod[, 2]
     }   
@@ -142,14 +144,14 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       
     } else {
       
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "ordinal") %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "ordinal") %dopar% {
         fit2 <- ordinal::clm( target ~., data = dataset[, c(csIndex, i)], weights = wei )
         lik2[i] <- as.numeric( logLik(fit2) )
         return( c(lik2, length( coef(fit2) ) ) )
       } 
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- 2 * (mod[, 1] - lik1)
       pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
       
@@ -158,7 +160,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
   } else if ( identical(test, testIndMultinom) ) {  ## multinomial regression
     
     target = as.factor( as.numeric( target ) )
-    fit1 = nnet::multinom( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, trace = FALSE )
+    fit1 <- nnet::multinom( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, trace = FALSE )
     lik1 = as.numeric( logLik(fit1) )
     d1 = length( coef(fit1) )
     
@@ -166,24 +168,24 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       lik2 <- dof <- numeric( cols )
       for ( i in xIndex ) {
         fit2 = nnet::multinom( target ~., data = dataset[, c(csIndex, i)], weights = wei, trace = FALSE )
-        lik2[i] = as.numeric( logLik(fit2) )
-        dof[i] = length( coef(fit2) ) 
+        lik2[i] <- as.numeric( logLik(fit2) )
+        dof[i] <- length( coef(fit2) ) 
       }
-      models$stat = 2 * (lik2 - lik1)
-      models$pvalue = pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
+      models$stat <- 2 * (lik2 - lik1)
+      models$pvalue <- pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "nnet") %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "nnet") %dopar% {
         fit2 = nnet::multinom( target ~., data = dataset[, c(csIndex, i)], weights = wei, trace = FALSE )
         lik2 = as.numeric( logLik(fit2 ) )
         return( c(lik2, length( coef(fit2) ) ) )
         
       }
-      stopCluster(cl)
-      models$stat = 2 * (mod[, 1] - lik1)
-      models$pvalue = pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
+      parallel::stopCluster(cl)
+      models$stat <- 2 * (mod[, 1] - lik1)
+      models$pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
     }
     
   } else if ( identical(test, testIndLogistic) ) {  ## Logistic regression
@@ -195,23 +197,23 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       lik2 <- dof <- numeric( cols )
       for ( i in xIndex ) {
         fit2 = glm( target ~., data = dataset[, c(csIndex, i)], binomial, weights = wei )
-        lik2[i] = fit2$deviance
-        dof[i] = length( fit2$coefficients ) 
+        lik2[i] <- fit2$deviance
+        dof[i] <- length( fit2$coefficients ) 
       }
-      models$stat = lik1 - lik2
-      models$pvalue = pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
+      models$stat <- lik1 - lik2
+      models$pvalue <- pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 = glm( target ~., data = dataset[, c(csIndex, i)], binomial, weights = wei )
         lik2 = fit2$deviance
         return( c(lik2, length( fit2$coefficients ) ) )
       }
-      stopCluster(cl)
-      models$stat = lik1 - mod[, 1]
-      models$pvalue = pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
+      parallel::stopCluster(cl)
+      models$stat <- lik1 - mod[, 1]
+      models$pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
     }
     
   } else if ( identical(test, testIndBinom) ) {  ## Binomial regression
@@ -232,22 +234,22 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       wei <- target[, 2] 
       y <- target[, 1] / wei
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 = glm( y ~., data = dataset[, c(csIndex, i)], binomial, weights = wei )
         lik2 = as.numeric( logLik(fit2) )
         return( c(lik2, length( fit2$coefficients ) ) )
       }
-      stopCluster(cl)
-      models$stat = as.vector( lik1 - mod[, 1] )
-      models$pvalue = pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
+      parallel::stopCluster(cl)
+      models$stat <- as.vector( lik1 - mod[, 1] )
+      models$pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
     }
 
   } else if ( identical(test, testIndPois) ) {  ## Poisson regression
-    fit1 = glm( target ~., data = dataset[, csIndex, drop = FALSE], poisson, weights = wei )
+    fit1 <- glm( target ~., data = dataset[, csIndex, drop = FALSE], poisson, weights = wei )
     lik1 = fit1$deviance
     d1 <- length(fit1$coefficients)
     
@@ -255,22 +257,22 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       lik2 <- dof <- numeric( cols )
       for ( i in xIndex ) {
         fit2 = glm( target ~., data = dataset[, c(csIndex, i)], poisson, weights = wei )
-        lik2[i] = fit2$deviance
-        dof[i] = length( fit2$coefficients ) 
+        lik2[i] <- fit2$deviance
+        dof[i] <- length( fit2$coefficients ) 
       }
-      models$stat = lik1 - lik2
-      models$pvalue = pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
+      models$stat <- lik1 - lik2
+      models$pvalue <- pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 = glm( target ~., data = dataset[, c(csIndex, i)], poisson, weights = wei )
         return( c(fit2$deviance, length( fit2$coefficients ) ) )
       }
-      stopCluster(cl)
-      models$stat = as.vector( lik1 - mod[, 1] )
-      models$pvalue = pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
+      parallel::stopCluster(cl)
+      models$stat <- as.vector( lik1 - mod[, 1] )
+      models$pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
     }
     
   } else if ( identical(test, testIndNB) ) {  ## Negative binomial regression
@@ -281,28 +283,28 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       lik2 <- dof <- numeric( cols )
       for ( i in xIndex ) {
         fit2 = MASS::glm.nb( target ~., data = dataset[, c(csIndex, i)], weights = wei )
-        lik2[i] = fit2$twologlik
-        dof[i] = length( fit2$coefficients ) 
+        lik2[i] <- fit2$twologlik
+        dof[i] <- length( fit2$coefficients ) 
       }
-      models$stat = lik2 - lik1
-      models$pvalue = pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
+      models$stat <- lik2 - lik1
+      models$pvalue <- pchisq(models$stat, dof - d1, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "MASS") %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "MASS") %dopar% {
         fit2 = MASS::glm.nb( target ~., data = dataset[, c(csIndex, i)], weights = wei )
         return( c(fit2$twologlik, length( fit2$coefficients ) ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- as.vector(mod[, 1]) - lik1
-      models$pvalue = pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
+      models$pvalue <- pchisq(models$stat, mod[, 2] - d1, lower.tail = FALSE, log.p = TRUE)
     }
     
   } else if ( identical(test, testIndQBinom)   ) {  ## Quasi Binomial regression
     
     if ( ncores <= 1 | is.null(ncores) ) {
-      fit1 = glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasibinomial(link = logit), weights = wei )
+      fit1 <- glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasibinomial(link = logit), weights = wei )
       for ( i in xIndex ) {
         fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = quasibinomial(link = logit), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
@@ -315,10 +317,10 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pvalue
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasibinomial(link = logit), weights = wei )
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = quasibinomial(link = logit), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
         stat <- tab[2, 5]
@@ -327,14 +329,14 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- mod[, 2]
     }
     
   } else if ( identical(test, testIndQPois)   ) {  ## Quasi Poisson regression
     stat <- pvalue <- numeric(cols)
-    fit1 = glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasipoisson(link = log), weights = wei )
+    fit1 <- glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasipoisson(link = log), weights = wei )
     
     if ( ncores <= 1 | is.null(ncores) ) {
       for ( i in xIndex ) {
@@ -349,10 +351,10 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pvalue
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- glm( target ~ ., data = dataset[, csIndex, drop = FALSE], family = quasipoisson(link = log), weights = wei )
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = quasipoisson(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
         stat <- tab[2, 5]
@@ -361,13 +363,13 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- mod[, 2]
     }
     
   } else if ( identical(test, testIndNormLog) ) {  ## Normal log link regression
-    fit1 = glm(target ~., data = dataset[, csIndex, drop = FALSE], family = gaussian(link = log), weights = wei)
+    fit1 <- glm(target ~., data = dataset[, csIndex, drop = FALSE], family = gaussian(link = log), weights = wei)
 
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- pvalue <- numeric( cols )
@@ -383,9 +385,9 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pvalue
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 <- glm( target ~ dataset[, i], family = gaussian(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
         stat <- tab[2, 5]
@@ -394,13 +396,13 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- mod[, 2]
     }
     
   } else if ( identical(test, testIndGamma)   ) {  ## Gamma regression
-    fit1 = glm(target ~., data = dataset[, csIndex, drop = FALSE], family = Gamma(link = log), weights = wei)
+    fit1 <- glm(target ~., data = dataset[, csIndex, drop = FALSE], family = Gamma(link = log), weights = wei)
 
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- pvalue <- numeric( cols )
@@ -416,9 +418,9 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pvalue
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = Gamma(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
         stat <- tab[2, 5]
@@ -427,13 +429,13 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- mod[, 2]
     } 
     
   } else if ( identical(test, testIndIGreg) ) {  ## Inverse Gaussian regression
-    fit1 = glm( target ~., data = dataset[, csIndex, drop = FALSE], family = inverse.gaussian(link = log), weights = wei )
+    fit1 <- glm( target ~., data = dataset[, csIndex, drop = FALSE], family = inverse.gaussian(link = log), weights = wei )
 
     if ( ncores <= 1 | is.null(ncores) ) {
       stat <- pvalue <- numeric( cols )
@@ -445,13 +447,13 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         df2 <- tab[2, 1]
         pvalue[i] <- pf(tab[2,5] ,df1,df2, lower.tail = FALSE, log.p = TRUE)
       }
-      models$stat = stat
-      models$pvalue = pvalue
+      models$stat <- stat
+      models$pvalue <- pvalue
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind) %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind) %dopar% {
         fit2 <- glm( target ~., data = dataset[, c(csIndex, i)], family = inverse.gaussian(link = log), weights = wei )
         tab <- anova(fit1, fit2, test = "F")
         stat <- tab[2, 5]
@@ -460,7 +462,7 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pvalue <- pf(tab[2, 5], df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pvalue ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- mod[, 2]
     }
@@ -491,14 +493,14 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         stat[i] = as.numeric( ww[[1]][3] )
         pval[i] = pf(stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE)
       }
-      models$stat = stat
-      models$pvalue = pval
+      models$stat <- stat
+      models$pvalue <- pval
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      fit1 = quantreg::rq(target ~., data = dataset[, csIndex, drop = FALSE], weights = wei)
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "quantreg") %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      fit1 <- quantreg::rq(target ~., data = dataset[, csIndex, drop = FALSE], weights = wei)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "quantreg") %dopar% {
         fit2 = quantreg::rq(target ~., data = dataset[, c(csIndex, i)], weights = wei )
         ww = anova(fit1, fit2, test = "rank")
         df1 = as.numeric( ww[[1]][1] )
@@ -507,9 +509,9 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
         pval = pf(stat, df1, df2, lower.tail = FALSE, log.p = TRUE)
         return( c(stat, pval ) )
       }
-      stopCluster(cl)
-      models$stat = as.vector( mod[, 1] )
-      models$pvalue = as.vector( mod[, 2] )
+      parallel::stopCluster(cl)
+      models$stat <- as.vector( mod[, 1] )
+      models$pvalue <- as.vector( mod[, 2] )
     }
     
   } else if ( identical(test, censIndCR) ) {  ## Cox regression
@@ -527,15 +529,15 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- survival::coxph( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei)
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
         fit2 <- survival::coxph( target ~., data = dataset[, c(csIndex, i)], weights = wei )
         res <- anova(fit2)
         return( c(res[2, 2], res[2, 3] ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- pchisq(mod[, 1], mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
@@ -555,17 +557,17 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, dof, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei )
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
         fit2 <- survival::survreg( target ~., data = dataset[, c(csIndex, i)], weights = wei )
         res <- anova(fit1, fit2)
         ## stat <- res[2, 6]
         ## dof <- res[2, 5]
         return( c( res[2, 6],res[2, 5] ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- pchisq(models$stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
@@ -585,17 +587,17 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, dof, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], dist = "exponential", weights = wei )
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
         fit2 <- survival::survreg( target ~., data = dataset[, c(csIndex, i)], dist = "exponential", weights = wei )
         res <- anova(fit1, fit2)
         ## stat <- res[2, 6]
         ## dof <- res[2, 5]
         return( c( res[2, 6],res[2, 5] ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- pchisq(models$stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
@@ -615,17 +617,17 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, dof, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, dist = "loglogistic" )
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
         fit2 <- survival::survreg( target ~., data = dataset[, c(csIndex, i)], weights = wei, dist = "loglogistic" )
         res <- anova(fit1, fit2)
         ## stat <- res[2, 6]
         ## dof <- res[2, 5]
         return( c( res[2, 6],res[2, 5] ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- mod[, 1]
       models$pvalue <- pchisq(models$stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
@@ -645,17 +647,17 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, dof, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      fit1 = survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, dist = "gaussian" )
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      fit1 <- survival::survreg( target ~., data = dataset[, csIndex, drop = FALSE], weights = wei, dist = "gaussian" )
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
         fit2 = survival::survreg( target ~., data = dataset[, c(csIndex, i)], weights = wei, dist = "gaussian" )
         res <- anova(fit1, fit2)
         return( c(res[2, 6], res[2, 5] ) )
       }
-      stopCluster(cl)
-      models$stat = mod[, 1]
-      models$pvalue = pchisq(models$stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
+      parallel::stopCluster(cl)
+      models$stat <- mod[, 1]
+      models$pvalue <- pchisq(models$stat, mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
     
   } else if ( identical(test, testIndClogit) ) {  ## Conditional logistic regression
@@ -674,15 +676,15 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       pvalue <- pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       fit1 <- survival::clogit( case ~., data = dataset[, csIndex, drop = FALSE] + strata(subject) ) 
-      mod <- foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .packages = "survival") %dopar% {
         fit2 <- survival::clogit( case ~., data = dataset[, c(csIndex, i)] + strata(subject) ) 
         res <- anova(fit1, fit2)
         return( c(res[2, 2], res[2, 3]) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- as.vector( mod[, 1] )
       models$pvalue <- pchisq(mod[, 1], mod[, 2], lower.tail = FALSE, log.p = TRUE)
     }
@@ -704,13 +706,13 @@ cond.regs <- function(target, dataset, xIndex, csIndex, test = NULL, wei = NULL,
       models$pvalue <- pchisq(models$stat, 2, lower.tail = FALSE, log.p = TRUE)
       
     } else {
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
-      mod <- foreach(i = xIndex, .combine = rbind, .pcakages = "Rfast", .export = "spml.reg") %dopar% {
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
+      mod <- foreach::foreach(i = xIndex, .combine = rbind, .pcakages = "Rfast", .export = "spml.reg") %dopar% {
         fit2 <- Rfast::spml.reg( target, dataset[, c(csIndex, i)] )
         return( fit2$loglik )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
       models$stat <- 2 * as.vector(mod) - lik1
       models$pvalue <- pchisq(models$stat, 2, lower.tail = FALSE, log.p = TRUE)
     }
