@@ -12,8 +12,8 @@ fbed.glmm.ordinal <- function(y, x, id, univ = NULL, alpha = 0.05, wei = NULL, K
   sa <- NULL
   pva <- NULL
   
-  ep <- Rfast::check_data(x)
-  if ( sum(ep>0) > 0 )  x[, ep] <- rnorm( n * ep )
+  zevar <- Rfast::check_data(x)
+  if ( sum( zevar > 0 ) > 0 )  x[, zevar] <- rnorm( n * length(zevar) )
   
   runtime <- proc.time()
   
@@ -28,6 +28,9 @@ fbed.glmm.ordinal <- function(y, x, id, univ = NULL, alpha = 0.05, wei = NULL, K
     univ <- list()
     univ$stat <- stat
     univ$pvalue <- pval
+	univ$stat[zevar] <- 0
+	univ$pvalue[zevar] <- 0
+	
   } else {
     n.tests <- 0
     stat <- univ$stat
@@ -68,11 +71,11 @@ fbed.glmm.ordinal <- function(y, x, id, univ = NULL, alpha = 0.05, wei = NULL, K
     card <- sum(sela > 0)
     
     if (K == 1) {
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + (1|id), weights = wei )
         lik2[i] <- logLik( fit2 )
       }
-      n.tests[2] <- length( ind[-sela] )
+      n.tests[2] <- length( ind[-c(sela, zevar)] )
       stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
@@ -109,11 +112,11 @@ fbed.glmm.ordinal <- function(y, x, id, univ = NULL, alpha = 0.05, wei = NULL, K
     
     if ( K > 1) {
       
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + (1|id), weights = wei )
         lik2[i] <- logLik( fit2 )
       }
-      n.tests[2] <- length( ind[-sela] ) 
+      n.tests[2] <- length( ind[-c(sela, zevar)] ) 
       stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
