@@ -1,4 +1,4 @@
-partialcor <- function(R, indx, indy, indz) {
+partialcor <- function(R, indx, indy, indz, n) {
   ## R is a correlation matrix
   ## i and j denote the two variables whose conditional correlation is to be estimated 
   ## k denotes the set of conditioning variables
@@ -14,6 +14,10 @@ partialcor <- function(R, indx, indy, indz) {
      r <-  - rho[1, 2] / sqrt(rho[1, 1] * rho[2, 2])
   }
     if ( abs(r) > 1 ) r <- 0.99999
-    r
+    z <- 0.5 * log( (1 + r) / (1 - r) ) * sqrt( n - sum(indz > 0) - 3 )
+    pvalue <- pt( abs(z), n - sum(indz > 0) - 3, lower.tail = FALSE, log.p = TRUE )
+    res <- c(r, pvalue)
+    names(res) <- c("partial cor", "p-value")
+    res
 }
 
