@@ -1,4 +1,4 @@
-testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,  wei =  NULL, univariateModels = NULL,
+testIndGLMMReg <- function(target, reps = NULL, group, dataset, xIndex, csIndex,  wei =  NULL, univariateModels = NULL,
  hash = FALSE, stat_hash = NULL, pvalue_hash = NULL, slopes = FALSE) {
   #   TESTINDGLMM Conditional Independence Test based on generalised linear mixed models for normal, binary ro discrete variables
   #   target: a vector containing the values of the target variable. 
@@ -12,7 +12,6 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
   #   csIndex: the indices of the variables to condition on. They can be mixed variables, either continous or categorical
   #   this method returns: the pvalue PVALUE, the statistic STAT.
   #cast factor into numeric vector
-  target <- as.numeric(as.vector(target));
   csIndex[which(is.na(csIndex))] = 0
   
   if( hash )  {
@@ -21,20 +20,20 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
     xcs <- c(xIndex,csIndex2)
     key <- paste(as.character(xcs) , collapse=" ");
     if( !is.null(stat_hash[key]) )  {
-      stat = stat_hash[key];
-      pvalue = pvalue_hash[key];
+      stat <- stat_hash[key];
+      pvalue <- pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
   #if the test cannot performed succesfully these are the returned values
-  pvalue = log(1);
-  stat = 0; 
+  pvalue <- log(1);
+  stat <- 0; 
   #information with respect to cs
   if ( !is.na(match(xIndex, csIndex)) )  {
-    if ( hash )  {      #update hash objects
-      stat_hash$key <- 0;#.set(stat_hash , key , 0)
-      pvalue_hash$key <- log(1);#.set(pvalue_hash , key , 1)
+    if ( hash )  {      # update hash objects
+      stat_hash$key <- 0    # .set(stat_hash, key, 0)
+      pvalue_hash$key <- log(1)   # .set(pvalue_hash, key, 1)
     }
     results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
@@ -50,6 +49,8 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
   cs <- dataset[ , csIndex];
   if (length(cs) == 0 || any( is.na(cs) ) )  cs = NULL;
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
+  oop <- options(warn = -1) 
+  on.exit( options(oop) )
   if ( length(cs) != 0 )  {
     if ( is.null(dim(cs)[2]) )  {     #cs is a vector
       if ( identical(x, cs) )  {    #if(!any(x == cs) == FALSE)
@@ -57,32 +58,30 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
           stat_hash$key <- 0;           #.set(stat_hash , key , 0)
           pvalue_hash$key <- log(1);           #.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, stat_hash = stat_hash, pvalue_hash = pvalue_hash)
         return(results);
       }
     } else { #more than one var
       for (col in 1:dim(cs)[2])  {
         if ( identical(x, cs[, col]) )  {   #if(!any(x == cs) == FALSE)
-          if ( hash )  {    #update hash objects
-            stat_hash$key <- 0;         #.set(stat_hash , key , 0)
-            pvalue_hash$key <- log(1);         #.set(pvalue_hash , key , 1)
+          if ( hash )  {    # update hash objects
+            stat_hash$key <- 0;         # .set(stat_hash, key, 0)
+            pvalue_hash$key <- log(1);         # .set(pvalue_hash, key, 1)
           }
-          results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, stat_hash = stat_hash, pvalue_hash = pvalue_hash)
           return(results);
         }
       }
     }
   }
   
-  
-  options(warn = -1)
- #if the conditioning set (cs) is empty, we use the t-test on the coefficient of x.
+  #if the conditioning set (cs) is empty, we use the t-test on the coefficient of x.
   if (length(cs) == 0)  {
     #if the univariate models have been already compute
     if ( !is.null(univariateModels) )  {
       pvalue <- univariateModels$pvalue[[xIndex]];
       stat <- univariateModels$stat[[xIndex]];
-      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash = stat_hash, pvalue_hash = pvalue_hash)
       return(results);
     }
    if ( is.null(reps) ) {
@@ -124,9 +123,9 @@ testIndGLMMReg = function(target, reps = NULL, group, dataset, xIndex, csIndex,
   }	
   #update hash objects
   if ( hash )  {
-    stat_hash$key <- stat;   #.set(stat_hash , key , stat)
-    pvalue_hash$key <- pvalue;    #.set(pvalue_hash , key , pvalue)
+    stat_hash$key <- stat   # .set(stat_hash, key, stat)
+    pvalue_hash$key <- pvalue    # .set(pvalue_hash, key, pvalue)
   }
-  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash = stat_hash, pvalue_hash = pvalue_hash);
   return(results);
 }
\ No newline at end of file
