@@ -1,5 +1,5 @@
-waldBeta = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL)
-{
+waldBeta <- function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL, 
+                     hash = FALSE, stat_hash=NULL, pvalue_hash=NULL){
   #initialization
   csIndex[ which( is.na(csIndex) ) ] = 0
   
@@ -34,9 +34,9 @@ waldBeta = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
     return(results);
   }
   #extract the data
-  x = dataset[ , xIndex];
-  cs = dataset[ , csIndex];
-  if ( length(cs) == 0 || any( is.na(cs) ) )  cs = NULL;
+  x <- dataset[ , xIndex];
+  cs <- dataset[ , csIndex];
+  if ( length(cs) == 0 || any( is.na(cs) ) )  cs <- NULL;
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 )   {
     if ( is.null(dim(cs)[2]) ) {  #cs is a vector
@@ -64,15 +64,15 @@ waldBeta = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
   #trycatch for dealing with errors
   res <- tryCatch(
     {
-      #if the conditioning set (cs) is empty, we use the t-test on the coefficient of x.
+      #if the conditioning set (cs) is empty, we use the t-test on the coefficient of x
       if (length(cs) == 0) {
         #Fitting beta regression
-        fit = beta.mod(target, x, wei = wei)
-      } else   fit = beta.mod(target, dataset[, c(csIndex, xIndex)], wei = wei )  ;
-      res = fit$be
-      pr = dim(res)[1]
-      stat = res[pr, 3]
-      pvalue = pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE) 
+        fit <- beta.mod(target, x, wei = wei)
+      } else  fit <- beta.mod(target, dataset[, c(csIndex, xIndex)], wei = wei )
+      res <- fit$be
+      pr <- dim(res)[1]
+      stat <- res[pr, 3]
+      pvalue <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE) 
       #update hash objects
       if ( hash ) {
         stat_hash[key] <- stat;#.set(stat_hash , key , stat)
@@ -80,13 +80,13 @@ waldBeta = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
       }
       #last error check
       if ( is.na(pvalue) || is.na(stat) ) {
-        pvalue = log(1);
-        stat = 0;
+        pvalue <- log(1);
+        stat <- 0;
       } else {
         #update hash objects
         if( hash ) {
-          stat_hash[key] <- stat;#.set(stat_hash , key , stat)
-          pvalue_hash[key] <- pvalue;#.set(pvalue_hash , key , pvalue)
+          stat_hash[key] <- stat   # .set(stat_hash , key , stat)
+          pvalue_hash[key] <- pvalue   # .set(pvalue_hash , key , pvalue)
         }
       }
       #testerrorcaseintrycatch(4);
@@ -94,8 +94,8 @@ waldBeta = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
       return(results);
     },
     error = function(cond) {
-      pvalue = log(1);
-      stat = 0;
+      pvalue <- log(1);
+      stat <- 0;
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     },
@@ -105,7 +105,7 @@ waldBeta = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMode
     #     message("Here's the original warning message:")
     #     message(cond)
     #   },
-    finally={}
+    finally = {}
   )
   
   return(res);
