@@ -1,6 +1,8 @@
 zip.reg <- function(target, dataset, wei = NULL, lgy = NULL) {
   
   n <- length(target)
+  oop <- options(warn = -1) 
+  on.exit( options(oop) ) 
   if ( NCOL(dataset) == 0 ) {
     if ( is.null(wei) ) {
       mod <- Rfast::zip.mle(target)
@@ -17,14 +19,13 @@ zip.reg <- function(target, dataset, wei = NULL, lgy = NULL) {
     poia <- which(target == 0)
     n0 <- length(poia)   ;    n1 <-  n - n0
     target1 <- target[ -poia ]    
-  
+    
     if ( is.null(wei) ) {
       mod <- glm.fit(x[-poia, ], target1, family = poisson(log) )
       p1 <- ( n0 - sum( exp( - mod$fitted.values ) ) ) / n
       g1 <- log( p1 / ( 1 - p1 ) )
       pa <- c( g1, mod$coefficients)
       pa[is.na(pa)] <- rnorm( sum(is.na(pa)) )
-      options(warn = -1)
       lik <- nlm( regzip, pa, y1 = target1, x = x, n1 = n1, poia = poia, iterlim = 10000 )
       lik2 <- optim( lik$estimate, regzip, y1 = target1, x = x, n1 = n1, poia = poia, control = list(maxit = 10000) )
       if ( is.null(lgy) )  lgy <- sum( lgamma(target1 + 1) )  
@@ -37,7 +38,6 @@ zip.reg <- function(target, dataset, wei = NULL, lgy = NULL) {
       g1 <- log( p1 / ( 1 - p1 ) )
       pa <- c( g1, mod$coefficients)
       pa[is.na(pa)] <- rnorm( sum(is.na(pa)) )
-      options(warn = -1)
       lik <- nlm( regzipwei, pa, y1 = target1, x = x, n1 = n1, w1 = w1, w0 = w0, iterlim = 10000 )
       lik2 <- optim( lik$estimate, regzipwei, y1 = target1, x = x, n1 = n1, w1 = w1, w0 = w0, control = list(maxit = 10000) )  
       if ( is.null(lgy) )  lgy <- sum( w1 * lgamma(target1 + 1) )  
